/****************************************************************************
 * Copyright Notice:                                                        *
 *  (c) Copyright 1995 by Stardock Systems, Inc. ALL RIGHTS RESERVED.       *
 *      This work protected by US Copyright Law.                            *
 *  You may not create derived works from this material.                    *
 ****************************************************************************
 * Name:            OPEN.CMD                                                *
 *                                                                          *
 * Description:     Script file to open a specified view for an object      *
 *                  (file or directory) using WPS open semantics.           *
 ****************************************************************************/

/* Register REXX utility package. */
if RxFuncQuery('SysLoadFuncs') then do
  call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
  call SysLoadFuncs
  end

/* Get arguments. */
Parse Arg Args
If Pos( '"', Args ) > 0 Then
    /* Handle quotes here. */
    Parse Arg '"'File'"' ' 'OpenMode
Else
    /* Unquoted string. */
    Parse Arg File OpenMode

If Arg() = 0 Then Do
    Call CharOut, 'Open current directory?  (yN)  '
    Key = SysGetKey( 'NOECHO' )
    Say
    Parse Upper Value Key With Key
    If Key <> 'Y' Then Do
        Say
        Say 'Usage:  OPEN [Directory|FileName] [DEFAULT|SETTINGS|DETAILS|TREE|ICON|NAVIGATE|TEXT]'
        Say
        Say 'NOTE: the second parameter may be abbreviated as:'
        Say
        Say '           D   DETAILS'
        Say '           S   SETTINGS'
        Say '           T   TREE/TEXT'
        Say '           I   ICON'
        Say '           N   NAVIGATE'
        Say
        Say 'Ommitting the second parameter opens the default view.'
        Exit
    End
End

/* If no file was provided, then open the current directory. */
If File = '' | File = '.' Then File = Directory()

/* Check for < char; if there, don't modify at all (it's an object id). */
If SubStr( File, 1, 1 ) <> '<' Then Do

    /* If implied root, then supply drive. */
    If SubStr( File, 1, 1 ) = '\' Then
        File = SubStr( Directory(), 1, 2 )||File

    /* If no ':\' is present, then imply the current directory. */
    Else If SubStr( File, 2, 2 ) <> ':\' Then Do
        NewFile = Directory()
        If SubStr( File, 1, 1 ) <> '\' & SubStr( NewFile, Length( NewFile ), 1) <> '\' Then NewFile = NewFile'\'
        File = NewFile||File
    End
End

/* Handle abbreviations of open mode. */
Parse Upper Value OpenMode With OpenMode
Select
    When SubStr( OpenMode, 1, 1 ) = 'D' Then OpenMode = DETAILS
    When SubStr( OpenMode, 1, 1 ) = 'S' Then OpenMode = SETTINGS
    When SubStr( OpenMode, 1, 1 ) = 'I' Then OpenMode = ICON
    When SubStr( OpenMode, 1, 1 ) = 'N' Then OpenMode = NAVIGATE
    When SubStr( OpenMode, 1, 1 ) = 'T' Then Do

        /* Is specification a file? */
        rc = SysFileTree( File, 'FileInfo', FO )
        If Translate( FileInfo.1 ) = Translate( File ) Then
            OpenMode = TEXT
        Else
            OpenMode = TREE
    End
    OtherWise Do
        If OpenMode = '' Then
            OpenMode = DEFAULT
    End
End

/* Open the object. */
Say 'Opening 'OpenMode' view for object "'File'".'

/* If file exists. */
If Stream( File, 'C', 'QUERY EXISTS' ) = '' Then Do
    Call CharOut File, ''
    Call CharOut File
    Call SysSetObjectData File, "OPEN="OpenMode";"
End
Else
    Call SysSetObjectData File, "OPEN="OpenMode";"

